
.. _`CIM data types`:

CIM data types
--------------

.. index:: pair: CIM data types; libraries

.. automodule:: pywbem._cim_types

.. autoclass:: pywbem.CIMType
    :members:
    :special-members:
    :exclude-members: __repr__,__str__,__init__,__weakref__
    :autosummary:

.. autoclass:: pywbem.CIMDateTime
    :members:
    :special-members:
    :exclude-members: __repr__,__str__,__init__,__weakref__
    :autosummary:

.. autoclass:: pywbem.MinutesFromUTC
    :members:
    :special-members:
    :exclude-members: __repr__,__str__,__init__,__weakref__
    :autosummary:

.. autoclass:: pywbem.Char16
    :members:
    :autosummary:

.. autoclass:: pywbem.CIMInt
    :members:
    :special-members:
    :exclude-members: __repr__,__str__,__init__,__weakref__
    :autosummary:

.. autoclass:: pywbem.Uint8
    :members:
    :autosummary:

.. autoclass:: pywbem.Sint8
    :members:
    :autosummary:

.. autoclass:: pywbem.Uint16
    :members:
    :autosummary:

.. autoclass:: pywbem.Sint16
    :members:
    :autosummary:

.. autoclass:: pywbem.Uint32
    :members:
    :autosummary:

.. autoclass:: pywbem.Sint32
    :members:
    :autosummary:

.. autoclass:: pywbem.Uint64
    :members:
    :autosummary:

.. autoclass:: pywbem.Sint64
    :members:
    :autosummary:

.. autoclass:: pywbem.CIMFloat
    :members:
    :special-members:
    :exclude-members: __repr__,__str__,__init__,__weakref__
    :autosummary:

.. autoclass:: pywbem.Real32
    :members:
    :autosummary:

.. autoclass:: pywbem.Real64
    :members:
    :autosummary:
